@@ -50,6 +50,8 @@ class table_objects:
         return result[0]
 
     def create(self, *args, **kwargs):
+        if len(kwargs) + 1 != len(self.obj.namespace):
+            raise ValueError("数据与命名域不符.")
         column = self.obj.repo.list_folder(path=self.obj.name, int=True)
         if len(column) == 0:
             column = 0
